@@ -39,6 +39,11 @@
 #include <string.h>		/* For size_t.t */
 #include <time.h>		/* For time_t. */
 
+# ifdef __cplusplus
+extern "C"
+{
+# endif
+
 /**
  * OATH_VERSION
  *
@@ -46,7 +51,7 @@
  * version number.  Used together with oath_check_version() to verify
  * header file and run-time library consistency.
  */
-#define OATH_VERSION "2.0.2"
+#define OATH_VERSION "2.4.1"
 
 /**
  * OATH_VERSION_NUMBER
@@ -270,6 +275,30 @@ oath_totp_validate2_callback (const char *secret,
 			      oath_validate_strcmp_function strcmp_otp,
 			      void *strcmp_handle);
 
+extern OATHAPI int
+oath_totp_validate3 (const char *secret,
+		     size_t secret_length,
+		     time_t now,
+		     unsigned time_step_size,
+		     time_t start_offset,
+		     size_t window,
+		     int *otp_pos,
+		     uint64_t *otp_counter,
+		     const char *otp);
+
+extern OATHAPI int
+oath_totp_validate3_callback (const char *secret,
+			      size_t secret_length,
+			      time_t now,
+			      unsigned time_step_size,
+			      time_t start_offset,
+			      unsigned digits,
+			      size_t window,
+			      int *otp_pos,
+			      uint64_t *otp_counter,
+			      oath_validate_strcmp_function strcmp_otp,
+			      void *strcmp_handle);
+
 /* Usersfile */
 
 extern OATHAPI int
@@ -280,4 +309,8 @@ oath_authenticate_usersfile (const char *usersfile,
 			     const char *passwd,
 			     time_t * last_otp);
 
+# ifdef __cplusplus
+}
+# endif
+
 #endif /* OATH_H */
